'use strict';

var { join } = require('path');

exports.load = function() {
    const pkgList = Editor.Package.getPackages({
        name: 'localization-editor',
        enable: true,
    });

    if (!pkgList || pkgList.length !== 1 || !pkgList[0]) {
        return;
    }

    const pkg = pkgList[0];
    if (pkg.version !== '1.0.0') {
        return;
    }

    var SceneProcessor = require(join(Editor.App.path, 'modules/editor-extensions/extensions/localization-editor/dist/core/service/scanner/processor/SceneProcessor.js'));
    SceneProcessor.default.prototype.process = async function process(assetInfo, translateItemValueMap) {
        this.translateItemValueMap = translateItemValueMap;
        let baseNode = null;
        let asset;
        if (assetInfo.type.includes('Scene')) {
            const sceneAsset = this.assetSerializeService.deserializeFile(assetInfo.file);
            baseNode = sceneAsset.scene;
            asset = sceneAsset;
        }
        else if (assetInfo.type.includes('Prefab')) {
            const prefabAsset = this.assetSerializeService.deserializeFile(assetInfo.file);
            baseNode = prefabAsset.data;
            asset = prefabAsset;
         }
         if (!baseNode)
            return [];
         const result = this.scan(baseNode.walk.bind(baseNode), assetInfo);
         if (result.length > 0) {
            this.assetSerializeService.serialize(assetInfo.file, asset);
         }
        return Promise.resolve(Array.from(result.values()));
    }

    var ComponentUnLoader = require(join(Editor.App.path, 'modules/editor-extensions/extensions/localization-editor/dist/core/service/scanner/processor/ComponentUnLoader.js'))
    ComponentUnLoader.default.prototype.process = function(assetInfo) {
        let baseNode = null;
        let asset;
        if (assetInfo.type.includes('Scene')) {
            const sceneAsset = this.assetSerializeService.deserializeFile(assetInfo.file);
            asset = sceneAsset;
            baseNode = sceneAsset.scene;
        }
        else if (assetInfo.type.includes('Prefab')) {
            const prefabAsset = this.assetSerializeService.deserializeFile(assetInfo.file);
            asset = prefabAsset;
            baseNode = prefabAsset.data;
        }
        if (!baseNode)
            return;
         const destroyCount = this.unloadComponent(baseNode.walk.bind(baseNode));
         if (destroyCount > 0) {
            this.assetSerializeService.serialize(assetInfo.file, asset);
        }
    };

    ComponentUnLoader.default.prototype.unloadComponent = function unloadComponent(walk) {
        let destroyCount = 0;
        walk((node) => {
            if (node instanceof cc.Node) {
                const SceneProcessor_1 = require(join(Editor.App.path, 'modules/editor-extensions/extensions/localization-editor/dist/core/service/scanner/processor/SceneProcessor.js'));
                const i18nLabel = node.getComponent(SceneProcessor_1.default.L10nLabelComponentName);
                if (i18nLabel) {
                    i18nLabel.destroy();
                    destroyCount += 1;
                }
                const icuComponent = node.getComponent(SceneProcessor_1.default.ICUComponentName);
                if (icuComponent) {
                    icuComponent.destroy();
                    destroyCount += 1;
                }
            }
        });
        const cc_1 = require("cc");
        cc_1.CCObject._deferredDestroy();
        return destroyCount;
    }
}

exports.unload = function() {}
